==> qt-creator-opensource-src-4.1.0.tar.gz: qt-creator-opensource-src-4.1.0/src/plugins/projectexplorer/devicesupport/devicecheckbuildstep.h <==
/****************************************************************************
**
** Copyright (C) 2016 Research In Motion
** Contact: KDAB (info@kdab.com)
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include "../buildstep.h"
#include "../projectexplorer_export.h"

namespace ProjectExplorer {

class BuildStepList;

class PROJECTEXPLORER_EXPORT DeviceCheckBuildStep : public BuildStep
{
    Q_OBJECT
public:
    DeviceCheckBuildStep(BuildStepList *bsl, Core::Id id);
    DeviceCheckBuildStep(BuildStepList *bsl, DeviceCheckBuildStep *bs);

    bool init(QList<const BuildStep *> &earlierSteps) override;

    void run(QFutureInterface<bool> &fi) override;

    BuildStepConfigWidget *createConfigWidget() override;

    static Core::Id stepId();
    static QString stepDisplayName();
};

} // namespace ProjectExplorer

==> qt-creator-opensource-src-4.9.2.tar.gz: qt-creator-opensource-src-4.9.2/src/plugins/projectexplorer/devicesupport/devicecheckbuildstep.h <==
/****************************************************************************
**
** Copyright (C) 2016 Research In Motion
** Contact: KDAB (info@kdab.com)
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include "../buildstep.h"
#include "../projectexplorer_export.h"

namespace ProjectExplorer {

class BuildStepList;

class PROJECTEXPLORER_EXPORT DeviceCheckBuildStep : public BuildStep
{
    Q_OBJECT
public:
    explicit DeviceCheckBuildStep(BuildStepList *bsl);

    bool init() override;
    void doRun() override;

    static Core::Id stepId();
    static QString displayName();
};

} // namespace ProjectExplorer
